=================
Jupyter notebooks
=================

`Jupyter notebooks`_ demonstrating use of the `dms_variants`_ package.


.. _`Jupyter notebooks`: https://jupyter.org/
.. _nbval: https://nbval.readthedocs.io
.. _dms_variants: https://jbloomlab.github.io/dms_variants/
